@@ -4,3 +4,6 @@ from autonetkit.nidb import DeviceModel as DeviceModel
 from autonetkit.ank_messaging import update_vis
 # for legacy compatability
 from autonetkit.ank_messaging import update_vis as update_http
+from autonetkit.load.initialize import initialize
+
+import autonetkit.topologies as topos
